# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class RuleEngineControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def handle_rule_engine_request_using_post(self, entity_type, entity_id, timeout, **kwargs):  # noqa: E501
        """Push entity message with timeout to the rule engine (handleRuleEngineRequest)  # noqa: E501

        Creates the Message with type 'REST_API_REQUEST' and payload taken from the request body. Uses specified Entity Id as the Rule Engine message originator. This method allows you to extend the regular platform API with the power of Rule Engine. You may use default and custom rule nodes to handle the message. The generated message contains two important metadata fields:   * **'serviceId'** to identify the platform server that received the request;  * **'requestUUID'** to identify the request and route possible response from the Rule Engine;  Use **'rest call reply'** rule node to push the reply from rule engine back as a REST API call response. The platform expects the timeout value in milliseconds.   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handle_rule_engine_request_using_post(entity_type, entity_id, timeout, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: A string value representing the entity type. For example, 'DEVICE' (required)
        :param str entity_id: A string value representing the entity id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param int timeout: Timeout to process the request in milliseconds (required)
        :param str body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.handle_rule_engine_request_using_post_with_http_info(entity_type, entity_id, timeout, **kwargs)  # noqa: E501
        else:
            (data) = self.handle_rule_engine_request_using_post_with_http_info(entity_type, entity_id, timeout, **kwargs)  # noqa: E501
            return data

    def handle_rule_engine_request_using_post_with_http_info(self, entity_type, entity_id, timeout, **kwargs):  # noqa: E501
        """Push entity message with timeout to the rule engine (handleRuleEngineRequest)  # noqa: E501

        Creates the Message with type 'REST_API_REQUEST' and payload taken from the request body. Uses specified Entity Id as the Rule Engine message originator. This method allows you to extend the regular platform API with the power of Rule Engine. You may use default and custom rule nodes to handle the message. The generated message contains two important metadata fields:   * **'serviceId'** to identify the platform server that received the request;  * **'requestUUID'** to identify the request and route possible response from the Rule Engine;  Use **'rest call reply'** rule node to push the reply from rule engine back as a REST API call response. The platform expects the timeout value in milliseconds.   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handle_rule_engine_request_using_post_with_http_info(entity_type, entity_id, timeout, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: A string value representing the entity type. For example, 'DEVICE' (required)
        :param str entity_id: A string value representing the entity id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param int timeout: Timeout to process the request in milliseconds (required)
        :param str body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['entity_type', 'entity_id', 'timeout', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method handle_rule_engine_request_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'entity_type' is set
        if ('entity_type' not in params or
                params['entity_type'] is None):
            raise ValueError("Missing the required parameter `entity_type` when calling `handle_rule_engine_request_using_post`")  # noqa: E501
        # verify the required parameter 'entity_id' is set
        if ('entity_id' not in params or
                params['entity_id'] is None):
            raise ValueError("Missing the required parameter `entity_id` when calling `handle_rule_engine_request_using_post`")  # noqa: E501
        # verify the required parameter 'timeout' is set
        if ('timeout' not in params or
                params['timeout'] is None):
            raise ValueError("Missing the required parameter `timeout` when calling `handle_rule_engine_request_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'entity_type' in params:
            path_params['entityType'] = params['entity_type']  # noqa: E501
        if 'entity_id' in params:
            path_params['entityId'] = params['entity_id']  # noqa: E501
        if 'timeout' in params:
            path_params['timeout'] = params['timeout']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/rule-engine/{entityType}/{entityId}/{timeout}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def handle_rule_engine_request_using_post1(self, entity_type, entity_id, queue_name, timeout, **kwargs):  # noqa: E501
        """Push entity message with timeout and specified queue to the rule engine (handleRuleEngineRequest)  # noqa: E501

        Creates the Message with type 'REST_API_REQUEST' and payload taken from the request body. Uses specified Entity Id as the Rule Engine message originator. This method allows you to extend the regular platform API with the power of Rule Engine. You may use default and custom rule nodes to handle the message. The generated message contains two important metadata fields:   * **'serviceId'** to identify the platform server that received the request;  * **'requestUUID'** to identify the request and route possible response from the Rule Engine;  Use **'rest call reply'** rule node to push the reply from rule engine back as a REST API call response. If request sent for Device/Device Profile or Asset/Asset Profile entity, specified queue will be used instead of the queue selected in the device or asset profile. The platform expects the timeout value in milliseconds.   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handle_rule_engine_request_using_post1(entity_type, entity_id, queue_name, timeout, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: A string value representing the entity type. For example, 'DEVICE' (required)
        :param str entity_id: A string value representing the entity id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param str queue_name: Queue name to process the request in the rule engine (required)
        :param int timeout: Timeout to process the request in milliseconds (required)
        :param str body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.handle_rule_engine_request_using_post1_with_http_info(entity_type, entity_id, queue_name, timeout, **kwargs)  # noqa: E501
        else:
            (data) = self.handle_rule_engine_request_using_post1_with_http_info(entity_type, entity_id, queue_name, timeout, **kwargs)  # noqa: E501
            return data

    def handle_rule_engine_request_using_post1_with_http_info(self, entity_type, entity_id, queue_name, timeout, **kwargs):  # noqa: E501
        """Push entity message with timeout and specified queue to the rule engine (handleRuleEngineRequest)  # noqa: E501

        Creates the Message with type 'REST_API_REQUEST' and payload taken from the request body. Uses specified Entity Id as the Rule Engine message originator. This method allows you to extend the regular platform API with the power of Rule Engine. You may use default and custom rule nodes to handle the message. The generated message contains two important metadata fields:   * **'serviceId'** to identify the platform server that received the request;  * **'requestUUID'** to identify the request and route possible response from the Rule Engine;  Use **'rest call reply'** rule node to push the reply from rule engine back as a REST API call response. If request sent for Device/Device Profile or Asset/Asset Profile entity, specified queue will be used instead of the queue selected in the device or asset profile. The platform expects the timeout value in milliseconds.   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handle_rule_engine_request_using_post1_with_http_info(entity_type, entity_id, queue_name, timeout, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: A string value representing the entity type. For example, 'DEVICE' (required)
        :param str entity_id: A string value representing the entity id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param str queue_name: Queue name to process the request in the rule engine (required)
        :param int timeout: Timeout to process the request in milliseconds (required)
        :param str body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['entity_type', 'entity_id', 'queue_name', 'timeout', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method handle_rule_engine_request_using_post1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'entity_type' is set
        if ('entity_type' not in params or
                params['entity_type'] is None):
            raise ValueError("Missing the required parameter `entity_type` when calling `handle_rule_engine_request_using_post1`")  # noqa: E501
        # verify the required parameter 'entity_id' is set
        if ('entity_id' not in params or
                params['entity_id'] is None):
            raise ValueError("Missing the required parameter `entity_id` when calling `handle_rule_engine_request_using_post1`")  # noqa: E501
        # verify the required parameter 'queue_name' is set
        if ('queue_name' not in params or
                params['queue_name'] is None):
            raise ValueError("Missing the required parameter `queue_name` when calling `handle_rule_engine_request_using_post1`")  # noqa: E501
        # verify the required parameter 'timeout' is set
        if ('timeout' not in params or
                params['timeout'] is None):
            raise ValueError("Missing the required parameter `timeout` when calling `handle_rule_engine_request_using_post1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'entity_type' in params:
            path_params['entityType'] = params['entity_type']  # noqa: E501
        if 'entity_id' in params:
            path_params['entityId'] = params['entity_id']  # noqa: E501
        if 'queue_name' in params:
            path_params['queueName'] = params['queue_name']  # noqa: E501
        if 'timeout' in params:
            path_params['timeout'] = params['timeout']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/rule-engine/{entityType}/{entityId}/{queueName}/{timeout}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def handle_rule_engine_request_using_post2(self, entity_type, entity_id, **kwargs):  # noqa: E501
        """Push entity message to the rule engine (handleRuleEngineRequest)  # noqa: E501

        Creates the Message with type 'REST_API_REQUEST' and payload taken from the request body. Uses specified Entity Id as the Rule Engine message originator. This method allows you to extend the regular platform API with the power of Rule Engine. You may use default and custom rule nodes to handle the message. The generated message contains two important metadata fields:   * **'serviceId'** to identify the platform server that received the request;  * **'requestUUID'** to identify the request and route possible response from the Rule Engine;  Use **'rest call reply'** rule node to push the reply from rule engine back as a REST API call response. The default timeout of the request processing is 10 seconds.   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handle_rule_engine_request_using_post2(entity_type, entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: A string value representing the entity type. For example, 'DEVICE' (required)
        :param str entity_id: A string value representing the entity id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param str body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.handle_rule_engine_request_using_post2_with_http_info(entity_type, entity_id, **kwargs)  # noqa: E501
        else:
            (data) = self.handle_rule_engine_request_using_post2_with_http_info(entity_type, entity_id, **kwargs)  # noqa: E501
            return data

    def handle_rule_engine_request_using_post2_with_http_info(self, entity_type, entity_id, **kwargs):  # noqa: E501
        """Push entity message to the rule engine (handleRuleEngineRequest)  # noqa: E501

        Creates the Message with type 'REST_API_REQUEST' and payload taken from the request body. Uses specified Entity Id as the Rule Engine message originator. This method allows you to extend the regular platform API with the power of Rule Engine. You may use default and custom rule nodes to handle the message. The generated message contains two important metadata fields:   * **'serviceId'** to identify the platform server that received the request;  * **'requestUUID'** to identify the request and route possible response from the Rule Engine;  Use **'rest call reply'** rule node to push the reply from rule engine back as a REST API call response. The default timeout of the request processing is 10 seconds.   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handle_rule_engine_request_using_post2_with_http_info(entity_type, entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: A string value representing the entity type. For example, 'DEVICE' (required)
        :param str entity_id: A string value representing the entity id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param str body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['entity_type', 'entity_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method handle_rule_engine_request_using_post2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'entity_type' is set
        if ('entity_type' not in params or
                params['entity_type'] is None):
            raise ValueError("Missing the required parameter `entity_type` when calling `handle_rule_engine_request_using_post2`")  # noqa: E501
        # verify the required parameter 'entity_id' is set
        if ('entity_id' not in params or
                params['entity_id'] is None):
            raise ValueError("Missing the required parameter `entity_id` when calling `handle_rule_engine_request_using_post2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'entity_type' in params:
            path_params['entityType'] = params['entity_type']  # noqa: E501
        if 'entity_id' in params:
            path_params['entityId'] = params['entity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/rule-engine/{entityType}/{entityId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def handle_rule_engine_request_using_post3(self, **kwargs):  # noqa: E501
        """Push user message to the rule engine (handleRuleEngineRequest)  # noqa: E501

        Creates the Message with type 'REST_API_REQUEST' and payload taken from the request body. Uses current User Id ( the one which credentials is used to perform the request) as the Rule Engine message originator. This method allows you to extend the regular platform API with the power of Rule Engine. You may use default and custom rule nodes to handle the message. The generated message contains two important metadata fields:   * **'serviceId'** to identify the platform server that received the request;  * **'requestUUID'** to identify the request and route possible response from the Rule Engine;  Use **'rest call reply'** rule node to push the reply from rule engine back as a REST API call response. The default timeout of the request processing is 10 seconds.   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handle_rule_engine_request_using_post3(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.handle_rule_engine_request_using_post3_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.handle_rule_engine_request_using_post3_with_http_info(**kwargs)  # noqa: E501
            return data

    def handle_rule_engine_request_using_post3_with_http_info(self, **kwargs):  # noqa: E501
        """Push user message to the rule engine (handleRuleEngineRequest)  # noqa: E501

        Creates the Message with type 'REST_API_REQUEST' and payload taken from the request body. Uses current User Id ( the one which credentials is used to perform the request) as the Rule Engine message originator. This method allows you to extend the regular platform API with the power of Rule Engine. You may use default and custom rule nodes to handle the message. The generated message contains two important metadata fields:   * **'serviceId'** to identify the platform server that received the request;  * **'requestUUID'** to identify the request and route possible response from the Rule Engine;  Use **'rest call reply'** rule node to push the reply from rule engine back as a REST API call response. The default timeout of the request processing is 10 seconds.   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handle_rule_engine_request_using_post3_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method handle_rule_engine_request_using_post3" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/rule-engine/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class ShortCustomerInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer_id': 'CustomerId',
        'title': 'str',
        'is_public': 'bool',
        'public': 'bool'
    }

    attribute_map = {
        'customer_id': 'customerId',
        'title': 'title',
        'is_public': 'isPublic',
        'public': 'public'
    }

    def __init__(self, customer_id=None, title=None, is_public=None, public=None):  # noqa: E501
        """ShortCustomerInfo - a model defined in Swagger"""  # noqa: E501
        self._customer_id = None
        self._title = None
        self._is_public = None
        self._public = None
        self.discriminator = None
        if customer_id is not None:
            self.customer_id = customer_id
        if title is not None:
            self.title = title
        if is_public is not None:
            self.is_public = is_public
        if public is not None:
            self.public = public

    @property
    def customer_id(self):
        """Gets the customer_id of this ShortCustomerInfo.  # noqa: E501


        :return: The customer_id of this ShortCustomerInfo.  # noqa: E501
        :rtype: CustomerId
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this ShortCustomerInfo.


        :param customer_id: The customer_id of this ShortCustomerInfo.  # noqa: E501
        :type: CustomerId
        """

        self._customer_id = customer_id

    @property
    def title(self):
        """Gets the title of this ShortCustomerInfo.  # noqa: E501

        Title of the customer.  # noqa: E501

        :return: The title of this ShortCustomerInfo.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ShortCustomerInfo.

        Title of the customer.  # noqa: E501

        :param title: The title of this ShortCustomerInfo.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def is_public(self):
        """Gets the is_public of this ShortCustomerInfo.  # noqa: E501


        :return: The is_public of this ShortCustomerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this ShortCustomerInfo.


        :param is_public: The is_public of this ShortCustomerInfo.  # noqa: E501
        :type: bool
        """

        self._is_public = is_public

    @property
    def public(self):
        """Gets the public of this ShortCustomerInfo.  # noqa: E501


        :return: The public of this ShortCustomerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this ShortCustomerInfo.


        :param public: The public of this ShortCustomerInfo.  # noqa: E501
        :type: bool
        """

        self._public = public

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShortCustomerInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShortCustomerInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class ComponentDescriptor(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'ComponentDescriptorId',
        'created_time': 'int',
        'type': 'str',
        'scope': 'str',
        'clustering_mode': 'str',
        'name': 'str',
        'clazz': 'str',
        'configuration_version': 'int',
        'actions': 'str',
        'has_queue_name': 'bool',
        'configuration_descriptor': 'JsonNode'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'type': 'type',
        'scope': 'scope',
        'clustering_mode': 'clusteringMode',
        'name': 'name',
        'clazz': 'clazz',
        'configuration_version': 'configurationVersion',
        'actions': 'actions',
        'has_queue_name': 'hasQueueName',
        'configuration_descriptor': 'configurationDescriptor'
    }

    def __init__(self, id=None, created_time=None, type=None, scope=None, clustering_mode=None, name=None, clazz=None, configuration_version=None, actions=None, has_queue_name=None, configuration_descriptor=None):  # noqa: E501
        """ComponentDescriptor - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._type = None
        self._scope = None
        self._clustering_mode = None
        self._name = None
        self._clazz = None
        self._configuration_version = None
        self._actions = None
        self._has_queue_name = None
        self._configuration_descriptor = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if type is not None:
            self.type = type
        if scope is not None:
            self.scope = scope
        if clustering_mode is not None:
            self.clustering_mode = clustering_mode
        if name is not None:
            self.name = name
        if clazz is not None:
            self.clazz = clazz
        if configuration_version is not None:
            self.configuration_version = configuration_version
        if actions is not None:
            self.actions = actions
        if has_queue_name is not None:
            self.has_queue_name = has_queue_name
        if configuration_descriptor is not None:
            self.configuration_descriptor = configuration_descriptor

    @property
    def id(self):
        """Gets the id of this ComponentDescriptor.  # noqa: E501


        :return: The id of this ComponentDescriptor.  # noqa: E501
        :rtype: ComponentDescriptorId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ComponentDescriptor.


        :param id: The id of this ComponentDescriptor.  # noqa: E501
        :type: ComponentDescriptorId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this ComponentDescriptor.  # noqa: E501

        Timestamp of the descriptor creation, in milliseconds  # noqa: E501

        :return: The created_time of this ComponentDescriptor.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this ComponentDescriptor.

        Timestamp of the descriptor creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this ComponentDescriptor.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def type(self):
        """Gets the type of this ComponentDescriptor.  # noqa: E501

        Type of the Rule Node  # noqa: E501

        :return: The type of this ComponentDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ComponentDescriptor.

        Type of the Rule Node  # noqa: E501

        :param type: The type of this ComponentDescriptor.  # noqa: E501
        :type: str
        """
        allowed_values = ["ENRICHMENT", "FILTER", "TRANSFORMATION", "ACTION", "EXTERNAL", "FLOW"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def scope(self):
        """Gets the scope of this ComponentDescriptor.  # noqa: E501

        Scope of the Rule Node. Always set to 'TENANT', since no rule chains on the 'SYSTEM' level yet.  # noqa: E501

        :return: The scope of this ComponentDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this ComponentDescriptor.

        Scope of the Rule Node. Always set to 'TENANT', since no rule chains on the 'SYSTEM' level yet.  # noqa: E501

        :param scope: The scope of this ComponentDescriptor.  # noqa: E501
        :type: str
        """
        allowed_values = ["TENANT"]  # noqa: E501
        if scope not in allowed_values:
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def clustering_mode(self):
        """Gets the clustering_mode of this ComponentDescriptor.  # noqa: E501

        Clustering mode of the RuleNode. This mode represents the ability to start Rule Node in multiple microservices.  # noqa: E501

        :return: The clustering_mode of this ComponentDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._clustering_mode

    @clustering_mode.setter
    def clustering_mode(self, clustering_mode):
        """Sets the clustering_mode of this ComponentDescriptor.

        Clustering mode of the RuleNode. This mode represents the ability to start Rule Node in multiple microservices.  # noqa: E501

        :param clustering_mode: The clustering_mode of this ComponentDescriptor.  # noqa: E501
        :type: str
        """
        allowed_values = ["USER_PREFERENCE", "ENABLED", "SINGLETON"]  # noqa: E501
        if clustering_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `clustering_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(clustering_mode, allowed_values)
            )

        self._clustering_mode = clustering_mode

    @property
    def name(self):
        """Gets the name of this ComponentDescriptor.  # noqa: E501

        Name of the Rule Node. Taken from the @RuleNode annotation.  # noqa: E501

        :return: The name of this ComponentDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ComponentDescriptor.

        Name of the Rule Node. Taken from the @RuleNode annotation.  # noqa: E501

        :param name: The name of this ComponentDescriptor.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def clazz(self):
        """Gets the clazz of this ComponentDescriptor.  # noqa: E501

        Full name of the Java class that implements the Rule Engine Node interface.  # noqa: E501

        :return: The clazz of this ComponentDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._clazz

    @clazz.setter
    def clazz(self, clazz):
        """Sets the clazz of this ComponentDescriptor.

        Full name of the Java class that implements the Rule Engine Node interface.  # noqa: E501

        :param clazz: The clazz of this ComponentDescriptor.  # noqa: E501
        :type: str
        """

        self._clazz = clazz

    @property
    def configuration_version(self):
        """Gets the configuration_version of this ComponentDescriptor.  # noqa: E501

        Rule node configuration version. By default, this value is 0. If the rule node is a versioned node, this value might be greater than 0.  # noqa: E501

        :return: The configuration_version of this ComponentDescriptor.  # noqa: E501
        :rtype: int
        """
        return self._configuration_version

    @configuration_version.setter
    def configuration_version(self, configuration_version):
        """Sets the configuration_version of this ComponentDescriptor.

        Rule node configuration version. By default, this value is 0. If the rule node is a versioned node, this value might be greater than 0.  # noqa: E501

        :param configuration_version: The configuration_version of this ComponentDescriptor.  # noqa: E501
        :type: int
        """

        self._configuration_version = configuration_version

    @property
    def actions(self):
        """Gets the actions of this ComponentDescriptor.  # noqa: E501

        Rule Node Actions. Deprecated. Always null.  # noqa: E501

        :return: The actions of this ComponentDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this ComponentDescriptor.

        Rule Node Actions. Deprecated. Always null.  # noqa: E501

        :param actions: The actions of this ComponentDescriptor.  # noqa: E501
        :type: str
        """

        self._actions = actions

    @property
    def has_queue_name(self):
        """Gets the has_queue_name of this ComponentDescriptor.  # noqa: E501

        Indicates that the RuleNode supports queue name configuration.  # noqa: E501

        :return: The has_queue_name of this ComponentDescriptor.  # noqa: E501
        :rtype: bool
        """
        return self._has_queue_name

    @has_queue_name.setter
    def has_queue_name(self, has_queue_name):
        """Sets the has_queue_name of this ComponentDescriptor.

        Indicates that the RuleNode supports queue name configuration.  # noqa: E501

        :param has_queue_name: The has_queue_name of this ComponentDescriptor.  # noqa: E501
        :type: bool
        """

        self._has_queue_name = has_queue_name

    @property
    def configuration_descriptor(self):
        """Gets the configuration_descriptor of this ComponentDescriptor.  # noqa: E501


        :return: The configuration_descriptor of this ComponentDescriptor.  # noqa: E501
        :rtype: JsonNode
        """
        return self._configuration_descriptor

    @configuration_descriptor.setter
    def configuration_descriptor(self, configuration_descriptor):
        """Sets the configuration_descriptor of this ComponentDescriptor.


        :param configuration_descriptor: The configuration_descriptor of this ComponentDescriptor.  # noqa: E501
        :type: JsonNode
        """

        self._configuration_descriptor = configuration_descriptor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ComponentDescriptor, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ComponentDescriptor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE-SNAPSHOT
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class TranslationControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def download_full_translation(self, locale_code, **kwargs):  # noqa: E501
        """Download end-user all-to-one translation (downloadFullTranslation)  # noqa: E501

        Fetch the end-user translation for the specified locale. The result is a json file with merged user custom translation, system language translation and default locale translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_full_translation(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_full_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
        else:
            (data) = self.download_full_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
            return data

    def download_full_translation_with_http_info(self, locale_code, **kwargs):  # noqa: E501
        """Download end-user all-to-one translation (downloadFullTranslation)  # noqa: E501

        Fetch the end-user translation for the specified locale. The result is a json file with merged user custom translation, system language translation and default locale translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_full_translation_with_http_info(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_full_translation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError("Missing the required parameter `locale_code` when calling `download_full_translation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/full/{localeCode}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_java_locales(self, **kwargs):  # noqa: E501
        """Get list of available java locales (getAvailableJavaLocales)  # noqa: E501

        The result is map where key is locale code and value is locale language and country  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_java_locales(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: JsonNode
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_java_locales_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_available_java_locales_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_available_java_locales_with_http_info(self, **kwargs):  # noqa: E501
        """Get list of available java locales (getAvailableJavaLocales)  # noqa: E501

        The result is map where key is locale code and value is locale language and country  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_java_locales_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: JsonNode
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_java_locales" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/availableJavaLocales', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JsonNode',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_locales(self, **kwargs):  # noqa: E501
        """Get list of available locales (getAvailableLocales)  # noqa: E501

        Fetch the list of customized locales from all levels  Security check is performed to verify that the user has 'READ' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_locales(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: JsonNode
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_locales_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_available_locales_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_available_locales_with_http_info(self, **kwargs):  # noqa: E501
        """Get list of available locales (getAvailableLocales)  # noqa: E501

        Fetch the list of customized locales from all levels  Security check is performed to verify that the user has 'READ' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_locales_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: JsonNode
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_locales" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/availableLocales', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JsonNode',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_full_translation(self, locale_code, **kwargs):  # noqa: E501
        """Get end-user all-to-one translation (getFullTranslation)  # noqa: E501

        Fetch the end-user translation for specified locale. The result is the merge of user custom translation, system language translation and default locale translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_full_translation(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :param str if_none_match:
        :param str accept_encoding:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_full_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
        else:
            (data) = self.get_full_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
            return data

    def get_full_translation_with_http_info(self, locale_code, **kwargs):  # noqa: E501
        """Get end-user all-to-one translation (getFullTranslation)  # noqa: E501

        Fetch the end-user translation for specified locale. The result is the merge of user custom translation, system language translation and default locale translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_full_translation_with_http_info(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :param str if_none_match:
        :param str accept_encoding:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code', 'if_none_match', 'accept_encoding']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_full_translation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError("Missing the required parameter `locale_code` when calling `get_full_translation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}
        if 'if_none_match' in params:
            header_params['If-None-Match'] = params['if_none_match']  # noqa: E501
        if 'accept_encoding' in params:
            header_params['Accept-Encoding'] = params['accept_encoding']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/full/{localeCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JsonNode',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_login_page_translation(self, locale_code, **kwargs):  # noqa: E501
        """Get system translation for login page  # noqa: E501

        Fetch the end-user translation for specified locale.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_login_page_translation(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :param str if_none_match:
        :param str accept_encoding:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_login_page_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
        else:
            (data) = self.get_login_page_translation_with_http_info(locale_code, **kwargs)  # noqa: E501
            return data

    def get_login_page_translation_with_http_info(self, locale_code, **kwargs):  # noqa: E501
        """Get system translation for login page  # noqa: E501

        Fetch the end-user translation for specified locale.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_login_page_translation_with_http_info(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: Locale code (e.g. 'en_US'). (required)
        :param str if_none_match:
        :param str accept_encoding:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code', 'if_none_match', 'accept_encoding']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_login_page_translation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError("Missing the required parameter `locale_code` when calling `get_login_page_translation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}
        if 'if_none_match' in params:
            header_params['If-None-Match'] = params['if_none_match']  # noqa: E501
        if 'accept_encoding' in params:
            header_params['Accept-Encoding'] = params['accept_encoding']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/noauth/translation/login/{localeCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Resource',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_translation_for_basic_edit(self, locale_code, **kwargs):  # noqa: E501
        """Get end-user multi-translation for basic edit (getTranslationForBasicEdit)  # noqa: E501

        Fetch the translation info map where value is info object containing key translation, origin translation, translation of parent level, translation status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translation_for_basic_edit(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: (required)
        :return: JsonNode
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_translation_for_basic_edit_with_http_info(locale_code, **kwargs)  # noqa: E501
        else:
            (data) = self.get_translation_for_basic_edit_with_http_info(locale_code, **kwargs)  # noqa: E501
            return data

    def get_translation_for_basic_edit_with_http_info(self, locale_code, **kwargs):  # noqa: E501
        """Get end-user multi-translation for basic edit (getTranslationForBasicEdit)  # noqa: E501

        Fetch the translation info map where value is info object containing key translation, origin translation, translation of parent level, translation status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translation_for_basic_edit_with_http_info(locale_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str locale_code: (required)
        :return: JsonNode
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['locale_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_translation_for_basic_edit" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'locale_code' is set
        if ('locale_code' not in params or
                params['locale_code'] is None):
            raise ValueError("Missing the required parameter `locale_code` when calling `get_translation_for_basic_edit`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'locale_code' in params:
            path_params['localeCode'] = params['locale_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/edit/basic/{localeCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JsonNode',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_translation_infos(self, **kwargs):  # noqa: E501
        """Get Translation info (getTranslationInfos)  # noqa: E501

        Fetch the list of customized locales and corresponding details such as language display name, country display name and translation progress percentage.   Response example:   ```json [   {     \"localeCode\": \"uk_UA\",     \"language\": \"Ukrainian (українська)\",     \"country\": \"Україна\",     \"progress\": 32   },   {     \"localeCode\": \"es_ES\",     \"language\": \"Spanish (español)\",     \"country\": \"España\",     \"progress\": 79   }] ```  Security check is performed to verify that the user has 'READ' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translation_infos(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[TranslationInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_translation_infos_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_translation_infos_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_translation_infos_with_http_info(self, **kwargs):  # noqa: E501
        """Get Translation info (getTranslationInfos)  # noqa: E501

        Fetch the list of customized locales and corresponding details such as language display name, country display name and translation progress percentage.   Response example:   ```json [   {     \"localeCode\": \"uk_UA\",     \"language\": \"Ukrainian (українська)\",     \"country\": \"Україна\",     \"progress\": 32   },   {     \"localeCode\": \"es_ES\",     \"language\": \"Spanish (español)\",     \"country\": \"España\",     \"progress\": 79   }] ```  Security check is performed to verify that the user has 'READ' permission for the white labeling resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translation_infos_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[TranslationInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_translation_infos" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/translation/info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TranslationInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class RuleChain(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'RuleChainId',
        'created_time': 'int',
        'tenant_id': 'TenantId',
        'name': 'str',
        'type': 'str',
        'first_rule_node_id': 'RuleNodeId',
        'root': 'bool',
        'debug_mode': 'bool',
        'configuration': 'JsonNode',
        'additional_info': 'JsonNode'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'tenant_id': 'tenantId',
        'name': 'name',
        'type': 'type',
        'first_rule_node_id': 'firstRuleNodeId',
        'root': 'root',
        'debug_mode': 'debugMode',
        'configuration': 'configuration',
        'additional_info': 'additionalInfo'
    }

    def __init__(self, id=None, created_time=None, tenant_id=None, name=None, type=None, first_rule_node_id=None, root=None, debug_mode=None, configuration=None, additional_info=None):  # noqa: E501
        """RuleChain - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._tenant_id = None
        self._name = None
        self._type = None
        self._first_rule_node_id = None
        self._root = None
        self._debug_mode = None
        self._configuration = None
        self._additional_info = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        self.tenant_id = tenant_id
        self.name = name
        if type is not None:
            self.type = type
        if first_rule_node_id is not None:
            self.first_rule_node_id = first_rule_node_id
        if root is not None:
            self.root = root
        if debug_mode is not None:
            self.debug_mode = debug_mode
        if configuration is not None:
            self.configuration = configuration
        if additional_info is not None:
            self.additional_info = additional_info

    @property
    def id(self):
        """Gets the id of this RuleChain.  # noqa: E501


        :return: The id of this RuleChain.  # noqa: E501
        :rtype: RuleChainId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RuleChain.


        :param id: The id of this RuleChain.  # noqa: E501
        :type: RuleChainId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this RuleChain.  # noqa: E501

        Timestamp of the rule chain creation, in milliseconds  # noqa: E501

        :return: The created_time of this RuleChain.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this RuleChain.

        Timestamp of the rule chain creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this RuleChain.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this RuleChain.  # noqa: E501


        :return: The tenant_id of this RuleChain.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this RuleChain.


        :param tenant_id: The tenant_id of this RuleChain.  # noqa: E501
        :type: TenantId
        """
        if tenant_id is None:
            raise ValueError("Invalid value for `tenant_id`, must not be `None`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def name(self):
        """Gets the name of this RuleChain.  # noqa: E501

        Rule Chain name  # noqa: E501

        :return: The name of this RuleChain.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RuleChain.

        Rule Chain name  # noqa: E501

        :param name: The name of this RuleChain.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this RuleChain.  # noqa: E501

        Rule Chain type. 'EDGE' rule chains are processing messages on the edge devices only.  # noqa: E501

        :return: The type of this RuleChain.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RuleChain.

        Rule Chain type. 'EDGE' rule chains are processing messages on the edge devices only.  # noqa: E501

        :param type: The type of this RuleChain.  # noqa: E501
        :type: str
        """
        allowed_values = ["CORE", "EDGE"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def first_rule_node_id(self):
        """Gets the first_rule_node_id of this RuleChain.  # noqa: E501


        :return: The first_rule_node_id of this RuleChain.  # noqa: E501
        :rtype: RuleNodeId
        """
        return self._first_rule_node_id

    @first_rule_node_id.setter
    def first_rule_node_id(self, first_rule_node_id):
        """Sets the first_rule_node_id of this RuleChain.


        :param first_rule_node_id: The first_rule_node_id of this RuleChain.  # noqa: E501
        :type: RuleNodeId
        """

        self._first_rule_node_id = first_rule_node_id

    @property
    def root(self):
        """Gets the root of this RuleChain.  # noqa: E501

        Indicates root rule chain. The root rule chain process messages from all devices and entities by default. User may configure default rule chain per device profile.  # noqa: E501

        :return: The root of this RuleChain.  # noqa: E501
        :rtype: bool
        """
        return self._root

    @root.setter
    def root(self, root):
        """Sets the root of this RuleChain.

        Indicates root rule chain. The root rule chain process messages from all devices and entities by default. User may configure default rule chain per device profile.  # noqa: E501

        :param root: The root of this RuleChain.  # noqa: E501
        :type: bool
        """

        self._root = root

    @property
    def debug_mode(self):
        """Gets the debug_mode of this RuleChain.  # noqa: E501

        Reserved for future usage.  # noqa: E501

        :return: The debug_mode of this RuleChain.  # noqa: E501
        :rtype: bool
        """
        return self._debug_mode

    @debug_mode.setter
    def debug_mode(self, debug_mode):
        """Sets the debug_mode of this RuleChain.

        Reserved for future usage.  # noqa: E501

        :param debug_mode: The debug_mode of this RuleChain.  # noqa: E501
        :type: bool
        """

        self._debug_mode = debug_mode

    @property
    def configuration(self):
        """Gets the configuration of this RuleChain.  # noqa: E501


        :return: The configuration of this RuleChain.  # noqa: E501
        :rtype: JsonNode
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this RuleChain.


        :param configuration: The configuration of this RuleChain.  # noqa: E501
        :type: JsonNode
        """

        self._configuration = configuration

    @property
    def additional_info(self):
        """Gets the additional_info of this RuleChain.  # noqa: E501


        :return: The additional_info of this RuleChain.  # noqa: E501
        :rtype: JsonNode
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this RuleChain.


        :param additional_info: The additional_info of this RuleChain.  # noqa: E501
        :type: JsonNode
        """

        self._additional_info = additional_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleChain, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleChain):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class TranslationInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'locale_code': 'str',
        'language': 'str',
        'country': 'str',
        'progress': 'int',
        'customized': 'bool'
    }

    attribute_map = {
        'locale_code': 'localeCode',
        'language': 'language',
        'country': 'country',
        'progress': 'progress',
        'customized': 'customized'
    }

    def __init__(self, locale_code=None, language=None, country=None, progress=None, customized=None):  # noqa: E501
        """TranslationInfo - a model defined in Swagger"""  # noqa: E501
        self._locale_code = None
        self._language = None
        self._country = None
        self._progress = None
        self._customized = None
        self.discriminator = None
        if locale_code is not None:
            self.locale_code = locale_code
        if language is not None:
            self.language = language
        if country is not None:
            self.country = country
        if progress is not None:
            self.progress = progress
        if customized is not None:
            self.customized = customized

    @property
    def locale_code(self):
        """Gets the locale_code of this TranslationInfo.  # noqa: E501

        Locale code formed by combining the ISO 639-1 language code and the ISO 3166-1 region code. For example, \"en_US\"  # noqa: E501

        :return: The locale_code of this TranslationInfo.  # noqa: E501
        :rtype: str
        """
        return self._locale_code

    @locale_code.setter
    def locale_code(self, locale_code):
        """Sets the locale_code of this TranslationInfo.

        Locale code formed by combining the ISO 639-1 language code and the ISO 3166-1 region code. For example, \"en_US\"  # noqa: E501

        :param locale_code: The locale_code of this TranslationInfo.  # noqa: E501
        :type: str
        """

        self._locale_code = locale_code

    @property
    def language(self):
        """Gets the language of this TranslationInfo.  # noqa: E501

        Locale code language display name. For example, \"Polish (Polski)\"  # noqa: E501

        :return: The language of this TranslationInfo.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this TranslationInfo.

        Locale code language display name. For example, \"Polish (Polski)\"  # noqa: E501

        :param language: The language of this TranslationInfo.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def country(self):
        """Gets the country of this TranslationInfo.  # noqa: E501

        Locale code country display name. For example, \"Poland\"  # noqa: E501

        :return: The country of this TranslationInfo.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this TranslationInfo.

        Locale code country display name. For example, \"Poland\"  # noqa: E501

        :param country: The country of this TranslationInfo.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def progress(self):
        """Gets the progress of this TranslationInfo.  # noqa: E501

        Number representing translation percentage progress. For example, 40 that means 40% of all keys are translated.  # noqa: E501

        :return: The progress of this TranslationInfo.  # noqa: E501
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this TranslationInfo.

        Number representing translation percentage progress. For example, 40 that means 40% of all keys are translated.  # noqa: E501

        :param progress: The progress of this TranslationInfo.  # noqa: E501
        :type: int
        """

        self._progress = progress

    @property
    def customized(self):
        """Gets the customized of this TranslationInfo.  # noqa: E501

        Boolean representing if current language has customization.  # noqa: E501

        :return: The customized of this TranslationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._customized

    @customized.setter
    def customized(self, customized):
        """Sets the customized of this TranslationInfo.

        Boolean representing if current language has customization.  # noqa: E501

        :param customized: The customized of this TranslationInfo.  # noqa: E501
        :type: bool
        """

        self._customized = customized

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TranslationInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranslationInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class EntityDataPageLink(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page_size': 'int',
        'page': 'int',
        'text_search': 'str',
        'sort_order': 'EntityDataSortOrder',
        'dynamic': 'bool'
    }

    attribute_map = {
        'page_size': 'pageSize',
        'page': 'page',
        'text_search': 'textSearch',
        'sort_order': 'sortOrder',
        'dynamic': 'dynamic'
    }

    def __init__(self, page_size=None, page=None, text_search=None, sort_order=None, dynamic=None):  # noqa: E501
        """EntityDataPageLink - a model defined in Swagger"""  # noqa: E501
        self._page_size = None
        self._page = None
        self._text_search = None
        self._sort_order = None
        self._dynamic = None
        self.discriminator = None
        if page_size is not None:
            self.page_size = page_size
        if page is not None:
            self.page = page
        if text_search is not None:
            self.text_search = text_search
        if sort_order is not None:
            self.sort_order = sort_order
        if dynamic is not None:
            self.dynamic = dynamic

    @property
    def page_size(self):
        """Gets the page_size of this EntityDataPageLink.  # noqa: E501


        :return: The page_size of this EntityDataPageLink.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this EntityDataPageLink.


        :param page_size: The page_size of this EntityDataPageLink.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def page(self):
        """Gets the page of this EntityDataPageLink.  # noqa: E501


        :return: The page of this EntityDataPageLink.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this EntityDataPageLink.


        :param page: The page of this EntityDataPageLink.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def text_search(self):
        """Gets the text_search of this EntityDataPageLink.  # noqa: E501


        :return: The text_search of this EntityDataPageLink.  # noqa: E501
        :rtype: str
        """
        return self._text_search

    @text_search.setter
    def text_search(self, text_search):
        """Sets the text_search of this EntityDataPageLink.


        :param text_search: The text_search of this EntityDataPageLink.  # noqa: E501
        :type: str
        """

        self._text_search = text_search

    @property
    def sort_order(self):
        """Gets the sort_order of this EntityDataPageLink.  # noqa: E501


        :return: The sort_order of this EntityDataPageLink.  # noqa: E501
        :rtype: EntityDataSortOrder
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this EntityDataPageLink.


        :param sort_order: The sort_order of this EntityDataPageLink.  # noqa: E501
        :type: EntityDataSortOrder
        """

        self._sort_order = sort_order

    @property
    def dynamic(self):
        """Gets the dynamic of this EntityDataPageLink.  # noqa: E501


        :return: The dynamic of this EntityDataPageLink.  # noqa: E501
        :rtype: bool
        """
        return self._dynamic

    @dynamic.setter
    def dynamic(self, dynamic):
        """Sets the dynamic of this EntityDataPageLink.


        :param dynamic: The dynamic of this EntityDataPageLink.  # noqa: E501
        :type: bool
        """

        self._dynamic = dynamic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EntityDataPageLink, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntityDataPageLink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class FeaturesInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sms_enabled': 'bool',
        'oauth_enabled': 'bool',
        'white_labeling_enabled': 'bool',
        'two_fa_enabled': 'bool',
        'email_enabled': 'bool',
        'notification_enabled': 'bool'
    }

    attribute_map = {
        'sms_enabled': 'smsEnabled',
        'oauth_enabled': 'oauthEnabled',
        'white_labeling_enabled': 'whiteLabelingEnabled',
        'two_fa_enabled': 'twoFaEnabled',
        'email_enabled': 'emailEnabled',
        'notification_enabled': 'notificationEnabled'
    }

    def __init__(self, sms_enabled=None, oauth_enabled=None, white_labeling_enabled=None, two_fa_enabled=None, email_enabled=None, notification_enabled=None):  # noqa: E501
        """FeaturesInfo - a model defined in Swagger"""  # noqa: E501
        self._sms_enabled = None
        self._oauth_enabled = None
        self._white_labeling_enabled = None
        self._two_fa_enabled = None
        self._email_enabled = None
        self._notification_enabled = None
        self.discriminator = None
        if sms_enabled is not None:
            self.sms_enabled = sms_enabled
        if oauth_enabled is not None:
            self.oauth_enabled = oauth_enabled
        if white_labeling_enabled is not None:
            self.white_labeling_enabled = white_labeling_enabled
        if two_fa_enabled is not None:
            self.two_fa_enabled = two_fa_enabled
        if email_enabled is not None:
            self.email_enabled = email_enabled
        if notification_enabled is not None:
            self.notification_enabled = notification_enabled

    @property
    def sms_enabled(self):
        """Gets the sms_enabled of this FeaturesInfo.  # noqa: E501


        :return: The sms_enabled of this FeaturesInfo.  # noqa: E501
        :rtype: bool
        """
        return self._sms_enabled

    @sms_enabled.setter
    def sms_enabled(self, sms_enabled):
        """Sets the sms_enabled of this FeaturesInfo.


        :param sms_enabled: The sms_enabled of this FeaturesInfo.  # noqa: E501
        :type: bool
        """

        self._sms_enabled = sms_enabled

    @property
    def oauth_enabled(self):
        """Gets the oauth_enabled of this FeaturesInfo.  # noqa: E501


        :return: The oauth_enabled of this FeaturesInfo.  # noqa: E501
        :rtype: bool
        """
        return self._oauth_enabled

    @oauth_enabled.setter
    def oauth_enabled(self, oauth_enabled):
        """Sets the oauth_enabled of this FeaturesInfo.


        :param oauth_enabled: The oauth_enabled of this FeaturesInfo.  # noqa: E501
        :type: bool
        """

        self._oauth_enabled = oauth_enabled

    @property
    def white_labeling_enabled(self):
        """Gets the white_labeling_enabled of this FeaturesInfo.  # noqa: E501


        :return: The white_labeling_enabled of this FeaturesInfo.  # noqa: E501
        :rtype: bool
        """
        return self._white_labeling_enabled

    @white_labeling_enabled.setter
    def white_labeling_enabled(self, white_labeling_enabled):
        """Sets the white_labeling_enabled of this FeaturesInfo.


        :param white_labeling_enabled: The white_labeling_enabled of this FeaturesInfo.  # noqa: E501
        :type: bool
        """

        self._white_labeling_enabled = white_labeling_enabled

    @property
    def two_fa_enabled(self):
        """Gets the two_fa_enabled of this FeaturesInfo.  # noqa: E501


        :return: The two_fa_enabled of this FeaturesInfo.  # noqa: E501
        :rtype: bool
        """
        return self._two_fa_enabled

    @two_fa_enabled.setter
    def two_fa_enabled(self, two_fa_enabled):
        """Sets the two_fa_enabled of this FeaturesInfo.


        :param two_fa_enabled: The two_fa_enabled of this FeaturesInfo.  # noqa: E501
        :type: bool
        """

        self._two_fa_enabled = two_fa_enabled

    @property
    def email_enabled(self):
        """Gets the email_enabled of this FeaturesInfo.  # noqa: E501


        :return: The email_enabled of this FeaturesInfo.  # noqa: E501
        :rtype: bool
        """
        return self._email_enabled

    @email_enabled.setter
    def email_enabled(self, email_enabled):
        """Sets the email_enabled of this FeaturesInfo.


        :param email_enabled: The email_enabled of this FeaturesInfo.  # noqa: E501
        :type: bool
        """

        self._email_enabled = email_enabled

    @property
    def notification_enabled(self):
        """Gets the notification_enabled of this FeaturesInfo.  # noqa: E501


        :return: The notification_enabled of this FeaturesInfo.  # noqa: E501
        :rtype: bool
        """
        return self._notification_enabled

    @notification_enabled.setter
    def notification_enabled(self, notification_enabled):
        """Sets the notification_enabled of this FeaturesInfo.


        :param notification_enabled: The notification_enabled of this FeaturesInfo.  # noqa: E501
        :type: bool
        """

        self._notification_enabled = notification_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeaturesInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeaturesInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
